@@ -25,7 +25,7 @@ class Client:
         else:
             endpoint = self.user_id + '-' + self.app + '-' + name + ".fly.dev" + ":443" # TODO convert to all lower case and dashes only
 
-        print("Connecting to endpoint: " + endpoint) # TODO remove this later so customer can't see this
+        # print("Connecting to endpoint: " + endpoint) # TODO remove this later so customer can't see this
         with grpc.insecure_channel(endpoint) as channel:
             stub = cakework_pb2_grpc.CakeworkStub(channel)
             response = stub.RunActivity(cakework_pb2.Request(parameters=json.dumps(request)))
